#pragma once
// zoomasm -- zoom video assembler
// (c) 2019,2020 Claude Heiland-Allen
// SPDX-License-Identifier: AGPL-3.0-or-later

#include <string>

#include "ffmpeg.h"

struct timeline;

extern struct timeline *timeline_new(void);
extern void timeline_delete(struct timeline *tl);

extern void seconds_to_timespec(double time, int timespec[4]);
extern double timespec_to_seconds(const int timespec[4]);

extern std::string format_timespec(const int timespec[4]);
extern std::string format_time(double time);
extern std::string format_time(const struct timeline *tl, double fraction);

extern bool timeline_set_time(struct timeline *tl, double seconds);
extern double timeline_get_time(const struct timeline *tl);
extern bool timeline_set_duration(struct timeline *tl, double seconds);
extern double timeline_get_duration(const struct timeline *tl);

extern void timeline_display_early(struct timeline *tl, int input_keyframe_count, bool enter_key_pressed, bool session_loaded);
extern void timeline_display_late(struct timeline *tl, double fps);

enum interpolation_mode
{
  interpolation_step = 0,
  interpolation_linear = 1,
  interpolation_cubic = 2
};

extern const char *interpolation_mode_string[3];

struct timestep
{
  double fraction;
  double phase;
  enum interpolation_mode mode;
};

extern struct timestep timeline_interpolate(struct timeline *tl, double fraction);

extern int timeline_get_count(const struct timeline *tl);
extern struct timestep timeline_get_timestep(const struct timeline *tl, int ix);
extern bool timeline_insert_timestep(struct timeline *tl, const struct timestep &ts);
extern bool timeline_clear(struct timeline *tl);
extern bool timeline_reset(struct timeline *tl);
extern bool timeline_is_valid(const struct timeline *tl);
